@@ -10,7 +10,7 @@ use Carp();
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.24';
+our $VERSION   = '0.25';
 
 sub _DEFAULT_STATE { return 'VIC' }
 
@@ -898,6 +898,9 @@ sub _compute_vic_grand_final_eve_day {    # i have no words ...
     if ( $year < 2015 ) {
         return ();
     }
+    elsif ( $year == 2021 ) {
+        return ();                            # not determined yet
+    }
     elsif ( $grand_final_eve_day{$year} ) {
         $day   = $grand_final_eve_day{$year}{day};
         $month = $grand_final_eve_day{$year}{month};
@@ -1153,6 +1156,9 @@ sub _compute_wa_queens_bday
         $day   = $wa_queens_bday{$year}{day};
         $month = $wa_queens_bday{$year}{month};
     }
+    elsif ( $year == 2022 ) {
+        return ();    # not determined yet
+    }
     else {
         Carp::croak(
             q[Don't know how to calculate Queen's Birthday in WA for this year]
@@ -1259,7 +1265,7 @@ Date::Holidays::AU - Determine Australian Public Holidays
 
 =head1 VERSION
  
-Version 0.23
+Version 0.25
 
 =head1 SYNOPSIS
 
